

<!-- <p align="center"><img src="misc/logo.png" width="150"/></p> -->
<p align="center"><img src="[](https://raw.githubusercontent.com/ismet55555/exam-terminal/master/misc/logo.png)" width="150"/></p>
<!-- https://raw.githubusercontent.com/ismet55555/exam-terminal/blob/master/misc/logo.png -->

<h1 align="center">exam-terminal</h1>

The exam-terminal is a terminal-based examination tool, which you can potentially do any of the following:

- Construct and take practice exams
- Give quick quizzes

Some mentionable features:

- Exam statistics
- Evaluation PDF

## Installation

- `pip install exam-terminal`

## Quick Start
- `exam-terminal --help`
- `exam-terminal exams/sample_exam.yml`

## Development

- Clone this repo
- Go into cloned repo directory directory
- `pipenv install --three --dev -e .`
- `pipenv shell`
